@@ -4,7 +4,7 @@ use MooseX::Params::Validate qw(validated_hash);
 
 use Bread::Board::Types;
 
-our $VERSION   = '0.20';
+our $VERSION   = '0.21';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'Bread::Board::Service';
@@ -15,7 +15,7 @@ has 'parameters' => (
     isa       => 'Bread::Board::Service::Parameters',
     lazy      => 1,
     coerce    => 1,
-    default   => sub { +{} },
+    builder   => '_build_parameters',
     handles   => {
         'has_parameters' => 'count'
     }
@@ -42,6 +42,8 @@ after 'get' => sub {
     $self->_clear_parameter_keys_to_remove;
 };
 
+sub _build_parameters { +{} }
+
 sub check_parameters {
     my $self = shift;
     return validated_hash(\@_, (
